@@ -2,7 +2,7 @@
 
 void Generator::namespaceOpen(std::ostream &out) const
 {
-    if (!d_nameSpace.empty())
+    if (d_nameSpace.size())
     {
         key(out);
         out <<  "namespace " << d_nameSpace << "\n"
