@@ -3,7 +3,7 @@
 void Scanner::checkEndOfRawString()
 {
     if (matched().rfind(d_rawString) == length() - d_rawString.length())
-        begin(StartCondition__::block);
+        begin(StartCondition_::block);
 
     more();
 }
