@@ -20,7 +20,7 @@ $insert namespace-open
 
 $insert polymorphic
 
-class \@Base
+$insert parserbase
 {
     public:
         enum DebugMode_
@@ -178,10 +178,7 @@ inline \@Base::STYPE_ &\@Base::vs_(int idx)
     return (d_vsp + idx)->second;
 }
 
-// hdr/tail
-// For convenience, when including ParserBase.h its symbols are available as
-// symbols in the class Parser, too.
-#define \@ \@Base
+$insert notokens
 
 $insert namespace-close
 
