@@ -3,7 +3,5 @@
 StateItem::StateItem(Item const &item)
 :
     d_item(item),
-    d_LA_enlarged(false),
-    d_next(string::npos),
-    d_nextEnlarged(false)
+    d_nextIdx(string::npos)
 {}
